@@ -2,6 +2,7 @@ from curses_toolkit.core import Cbreak
 
 
 def actions(parent, exit_actions, loop_actions={}, initial_focus=0):
+    ret = None
     parent.set_focus(initial_focus)
     with Cbreak():
         while True:
@@ -12,9 +13,24 @@ def actions(parent, exit_actions, loop_actions={}, initial_focus=0):
             except KeyError:
                 pass
             try:
-                exit_actions[k](parent.focus, parent)
+                ret = exit_actions[k](parent.focus, parent)
                 break
             except KeyError:
                 pass
+    parent.focus = None
+    parent.show()
+    return ret
+
+
+KEYS_VIM_SELECT = {
+        '\x1b': lambda i, ls: None,
+        'x': lambda i, ls: None,
+        '\n': lambda i, ls: i,
+        }
+
+KEYS_VIM_UP_DOWN = {
+        'k': lambda i, ls: ls.set_focus(ls.focus - 1),
+        'j': lambda i, ls: ls.set_focus(ls.focus + 1),
+        }
 
 # TODO: default actions dicts e.g. k & j for up & down
