@@ -9,6 +9,17 @@ class Cbreak:
         curses.nocbreak()
 
 
+class NoDelay:
+    def __init__(self, tenths_sec):
+        self.tenths_sec = tenths_sec
+
+    def __enter__(self):
+        curses.nodelay(self.tenths_sec)
+
+    def __exit__(self, *args):
+        curses.nocbreak()
+
+
 class Window:
     def __init__(self, row, col, height, width):
         self.row = row
